@@ -5,19 +5,21 @@ from email.message import EmailMessage
 
 import jinja2
 
-from .state import config as config_ctx
-from .state import event_listeners
-from .utils import allow_imports, prepare_event, silent_debug, time_limit
+from bitccl.state import config as config_ctx
+from bitccl.state import event_listeners
+from bitccl.utils import call_universal, function, prepare_event, silent_debug, time_limit
 
 PASSWORD_ALPHABET = string.ascii_uppercase + string.ascii_lowercase + string.digits + "-_"
 SECURE_PASSWORD_LENGTH = 43
 
 
+@function
 def add_event_listener(event, func):
     event = prepare_event(event)
     event_listeners[event].append(func)
 
 
+@function
 def on(event):
     def wrapper(func):
         add_event_listener(event, func)
@@ -25,18 +27,19 @@ def on(event):
     return wrapper
 
 
+@function
 def dispatch_event(event, *args, **kwargs):
     event = prepare_event(event)
     for listener in event_listeners[event]:
         try:
             with time_limit(30):
-                listener(*event.parsed_args, *args, **kwargs)
+                call_universal(listener, *event.parsed_args, *args, **kwargs)
         except BaseException:
             silent_debug()
             pass
 
 
-@allow_imports
+@function
 def template(name, data={}):
     try:
         with open(f"templates/{name}.j2") as f:
@@ -47,7 +50,7 @@ def template(name, data={}):
         return ""
 
 
-@allow_imports
+@function
 def send_email(to, subject, text):  # pragma: no cover
     try:
         config = config_ctx.get()
@@ -68,5 +71,6 @@ def send_email(to, subject, text):  # pragma: no cover
         return False
 
 
+@function
 def password(length=SECURE_PASSWORD_LENGTH):
     return "".join(secrets.choice(PASSWORD_ALPHABET) for _ in range(length))
